==> haskell-conduit-combinators-1.0.8.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.0.8.1
id: conduit-combinators-1.0.8.1-DRmFVgb5DSjLavKabQLkSd
key: conduit-combinators-1.0.8.1-DRmFVgb5DSjLavKabQLkSd
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 7a211f260c982ab4bd15f35709b0d02d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.0.8.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.0.8.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/conduit-combinators-1.0.8.1
hs-libraries: HSconduit-combinators-1.0.8.1-DRmFVgb5DSjLavKabQLkSd
depends:
    base-4.9.0.0 base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 chunked-data-0.3.0-1iVxL9iaWbrC0A3O3DXC6K
    conduit-1.2.8-AgdXmo7Kb3t3996td5STbV
    conduit-extra-1.1.15-DagxwJqUbBsFQRY5sqiDw4 filepath-1.4.1.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.1-9KQaQSkC3PNK28lhRPpgD0
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    resourcet-1.1.8-HXXNyeOqsSn6w8CKg5m7oy
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4 unix-2.7.2.0
    unix-compat-0.4.2.0-GNHotEMWE5dJ4oYFhgibIV
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-BXitqvas4xpGkaFQbixoM1
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-combinators-1.0.8.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.0.8.3
id: conduit-combinators-1.0.8.3-ju1IF9AJADEluzVPNl0Ne
key: conduit-combinators-1.0.8.3-ju1IF9AJADEluzVPNl0Ne
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 95a0f46e1b5d1fdc2b6aa715395c0d83
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.0.8.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.0.8.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/conduit-combinators-1.0.8.3
hs-libraries: HSconduit-combinators-1.0.8.3-ju1IF9AJADEluzVPNl0Ne
depends:
    base-4.9.0.0 base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 chunked-data-0.3.0-1iVxL9iaWbrC0A3O3DXC6K
    conduit-1.2.8-AgdXmo7Kb3t3996td5STbV
    conduit-extra-1.1.15-DagxwJqUbBsFQRY5sqiDw4 filepath-1.4.1.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.1-9KQaQSkC3PNK28lhRPpgD0
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    resourcet-1.1.8-HXXNyeOqsSn6w8CKg5m7oy
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4 unix-2.7.2.0
    unix-compat-0.4.2.0-GNHotEMWE5dJ4oYFhgibIV
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-BXitqvas4xpGkaFQbixoM1
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
